# atmospy: air quality data visualization


<!-- [![PyPI version](https://badge.fury.io/py/quantaq-cli.svg)](https://badge.fury.io/py/atmospy) -->
<!-- ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/atmospy)
[![license](https://img.shields.io/github/license/mashape/apistatus.svg)](https://github.com/quant-aq/atmospy/blob/master/LICENSE) -->
[![Tests](https://github.com/dhhagan/atmospy/actions/workflows/tests.yml/badge.svg)](https://github.com/dhhagan/atmospy/actions/workflows/tests.yml)
[![codecov](https://codecov.io/gh/dhhagan/atmospy/branch/main/graph/badge.svg)](https://codecov.io/gh/dhhagan/atmospy)
![Apache 2.0 licensed](https://img.shields.io/github/license/dhhagan/atmospy)


`atmospy` is a Python visualization library based on matplotlib and seaborn. 

## Documentation

Coming soon.

## Dependencies

### Supported Python versions

`atmospy` supports Python 3.8+.

### Mandatory dependencies

  * numpy
  * pandas
  * seaborn
  * matplotlib
  * scipy

## Installation

The latest stable release can by installed by installing directly from Github:

```sh
$ pip install git+https://github.com/dhhagan/atmospy.git
```

## Testing

## Development

`atmospy` development takes place on GitHub: https://github.com/dhhagan/atmospy

Please submit bugs that you encounter to the [issue tracker](https://github.com/dhhagan/atmospy/issues) with a reproducible example that clearly demonstrates the problem.